###################################################
### chunk number 1: setup
###################################################

	if( !file.exists( 'figs' ) ) dir.create( 'figs' )
	require(tikzDevice)
	
	# We need some extra options for controlling
	# Sweave output. Therefore we're going to bust
	# out and overwrite some core code with more
	# flexible alternatives.
	
	# *** Begin Mother of All R Hacks ****
	
	# We load a new Sweave function that contains a
	# more flexible set of output routines.
	source('patchSweave.R')
	
	# First, we find out where Sweave lives.
	env <- as.environment('package:utils')
	
	# And we break into it's house.
	unlockBinding('makeRweaveLatexCodeRunner',env)
	
	# And rearrange it's furniture....
	assignInNamespace('makeRweaveLatexCodeRunner',patchedCodeRunner,ns='utils')
	
	# ...and lock the door on the way out.
	lockBinding('makeRweaveLatexCodeRunner',env)
	
	#  But we take something with us when we leave...
	newCodeRunner <- utils:::makeRweaveLatexCodeRunner()
	
	# ...to stalk it down on the street...
	env <- grep('driver', lapply(sys.frames(),
		function(frame){ ls(envir=frame) }
	))
	env <- sys.frames()[[env]]
	
	# ...and give it a facelift.
	evalq( driver$runcode <- newCodeRunner, envir=env)
	
	# *** End Mother of All R Hacks ***
	
	# Now we have some extra code chunk options to play
	# with:
	#
	#   wrapoutput: a vector of two character strings that will be used
	#                       to surround R output chunks. Were formally hardwired
	#                       to '\n\begin{Soutput}\n' and '\n\end{Soutput}\n'.
	#
	#   wrapinput:  Same idea as wrapoutput- both of these options must be
	#                      set using options() as they are difficult to pass directly to
	#                      Sweave
	
	options( wrapoutput = c('\nswe@veSt@rtOutput','swe@veEndOutput\n') )
	


###################################################
### chunk number 2: tikzTitlePlot
###################################################

	tikz('figs/titlePlot.tex',bareBones=T,width=4,height=4)

	x <- seq(-4.5,4.5,length.out=100)
	y <- dnorm(x)

	xi <- seq(-2,2,length.out=30)
	yi <- dnorm(xi)

	plot(x,y,type='l',col='blue',ylab='$p(x)$',xlab='$x$')
	lines(xi,yi,type='s')
	lines(range(xi),c(0,0))
	lines(xi,yi,type='h')
	title(main="$p(x)=\\frac{1}{\\sqrt{2\\pi}}e^{-\\frac{x^2}{2}}$")
	int <- integrate(dnorm,min(xi),max(xi),subdivisions=length(xi))
	text(2.8,0.3,paste("\\small$\\displaystyle\\int_{",min(xi),"}^{",max(xi),"}p(x)dx\\approx",round(int[['value']],3),'$',sep=''))


	dev.off()


###################################################
### chunk number 3: pathStepIn
###################################################
	setwd('figs')


###################################################
### chunk number 4: simpleEx
###################################################
require(tikzDevice)
tikz('simpleEx.tex',width=3.5,height=3.5)
plot(1,main='Hello World!')
dev.off()


###################################################
### chunk number 5: latexEx
###################################################
require(tikzDevice)
tikz('latexEx.tex',
  width=3.5,height=3.5)

x <- rnorm(10)
y <- x + rnorm(5,sd=0.25)

model <- lm(y ~ x)
rsq <- summary( model )$r.squared
rsq <- signif(rsq,4)

plot(x,y,main='Hello \\LaTeX!')
abline(model,col='red')

mtext(paste("Linear model: $R^{2}=",
  rsq,"$" ),line=0.5)
  
legend('bottomright', legend = 
  paste("$y = ",
    round(coef(model)[2],3), 'x +',
    round(coef(model)[1],3), '$',
    sep=''), bty= 'n')

dev.off()


###################################################
### chunk number 6: bareBonesExample
###################################################
require(tikzDevice)
tikz('bareBonesExample.tex',width=4,height=4,bareBones=T)

x <- c(0,cumsum(rnorm(25)))
y <- c(0,cumsum(rnorm(25)))

plot(x, y, type="l" )

title("A Brownian Motion")

dev.off()


###################################################
### chunk number 7: standAloneExample
###################################################
require(tikzDevice)
tikz('standAloneExample.tex',standAlone=T)
plot(sin,-pi,2*pi,main="A Stand Alone TikZ Plot")
dev.off()


###################################################
### chunk number 8: standAloneCompileExample eval=FALSE
###################################################
## 
## 	require(tools)
## 	
## 	catch <- system(paste(Sys.which('pdflatex'),
## 		'-interaction=batchmode -output-directory figs/ figs/standAloneExample.tex'),
## 		ignore.stderr=T)
## 	
## 	# If compiling the example failed, we don't want to include a broken link.	
## 	if( catch == 0 ){
## 		pdfLink <- "The file \\\\code{standAloneExample.tex} may then be compiled to produce
## 			\\\\href{./figs/standAloneExample.pdf}{standAloneExample.pdf}. "
## 	}else{
## 		pdfLink <- ""
## 	}
##     #%\Sexpr{print(pdfLink)}


###################################################
### chunk number 9: annotation
###################################################
options(tikzLatexPackages = 
    c(getOption('tikzLatexPackages'),
        c("\\usetikzlibrary{decorations.pathreplacing}",
        "\\usetikzlibrary{shapes.arrows}")))

p <- rgamma(300,1)
outliers <- which( p > quantile(p,.75)+1.5*IQR(p) )

tikz("annotation.tex",width=4,height=4)
boxplot(p)

min.outlier <- grconvertY(min( p[outliers] ),, "device")
max.outlier <- grconvertY(max( p[outliers] ),, "device")
x <- grconvertX(1,,"device")

tikzAnnotate(paste("\\coordinate (min) at (",x,',',min.outlier,") {};"))
tikzAnnotate(paste("\\coordinate (max) at (",x,',',max.outlier,") {};"))

tikzAnnotate(c("\\draw[decorate,very thick,red,",
    "decoration={brace,amplitude=20pt}] (min) ",
    "-- node[single arrow,anchor=tip,fill=white,left=20pt,draw=green] ",
    "{Look at These Outliers!} (max);"))

tikzAnnotate(c("\\node[starburst, fill=green, ",
    "draw=blue, very thick,right=of max]  (burst) {Wow!};"))

tikzAnnotate(c("\\draw[->, very thick] (burst.west) -- (max);"))

dev.off()
setTikzDefaults()


###################################################
### chunk number 10: pathStepOut
###################################################
	setwd('../')


###################################################
### chunk number 11: strWidthDemo
###################################################
getLatexStrWidth( "The symbol: alpha" )
getLatexStrWidth( "The symbol: $\\alpha$" )


###################################################
### chunk number 12: charMetricDemo
###################################################
# Get metrics for 'y'
getLatexCharMetrics(121)

# Get metrics for 'x' - the second value is the descent
# and should be zero or very close to zero.
getLatexCharMetrics(120)


###################################################
### chunk number 13: charMetricErrors
###################################################
getLatexCharMetrics('y')
getLatexCharMetrics(20)

# Will return metrics for 'y'
getLatexCharMetrics(121.99)


